@@ -1,20 +1,20 @@
 package Acme::stickpin;
 
-use 5.10;
+use 5.006;
 use strict;
 use warnings;
 
 =head1 NAME
 
-Acme::stickpin - Testing
+Acme::stickpin - The great new Acme::stickpin!
 
 =head1 VERSION
 
-Version 0.02_02
+Version 0.01
 
 =cut
 
-our $VERSION = '0.02_02';
+our $VERSION = '0.01';
 
 
 =head1 SYNOPSIS
